@@ -1,9 +1,10 @@
 from znh5md.io.base import DataReader, DataWriter, ExplicitStepTimeChunk
-from znh5md.io.reader import AtomsReader
+from znh5md.io.reader import ASEFileReader, AtomsReader
 
 __all__ = [
     "DataReader",
     "DataWriter",
     "ExplicitStepTimeChunk",
     "AtomsReader",
+    "ASEFileReader",
 ]
