@@ -6,14 +6,15 @@ import functools
 import os
 import pathlib
 import typing
-import numpy as np
 
+import numpy as np
 import ase
 import dask.array
 import h5py
 from ase.calculators.singlepoint import SinglePointCalculator
 
-from znh5md.format import FormatHandler, GRP
+from znh5md.format import GRP, FormatHandler
+from znh5md.utils import rm_nan
 
 PATHLIKE = typing.Union[str, pathlib.Path, os.PathLike]
 
@@ -44,8 +45,12 @@ class DaskDataSet:
         time = dask.array.from_array(item["time"], chunks=time_chunks)
         step = dask.array.from_array(item["step"], chunks=time_chunks)
         species = dask.array.from_array(species["value"], chunks=time_chunks)
-        # assert species.step == item.step
-        # assert time_chunks == value_chunks[0] if not "auto"
+
+        if time.shape == ():
+            time = dask.array.arange(0, len(value) * time, time)
+
+        if step.shape == ():
+            step = dask.array.arange(0, len(value) * step, step)
 
         return cls(value=value, time=time, step=step, species=species)
 
@@ -175,6 +180,8 @@ class ASEH5MD(H5MDBase):
         information is not used in the ASE interface.
         """
         # not using dask here was 8x faster on a 32 MB h5 file
+        if item == GRP.boundary:
+            return getattr(self.format_handler, item)
         return getattr(self.format_handler, item)["value"]
 
     def get_atoms_list(self, item=None) -> typing.List[ase.Atoms]:
@@ -192,17 +199,21 @@ class ASEH5MD(H5MDBase):
             GRP.energy,
             GRP.forces,
             GRP.stress,
+            GRP.pbc,
         ]:
             with contextlib.suppress(AttributeError, KeyError):
-                data[key] = getattr(self, key)[item] if item else getattr(self, key)[:]
+                if key == GRP.boundary:
+                    data[key] = getattr(self, key)[:]
+                else:
+                    data[key] = (
+                        getattr(self, key)[item] if item else getattr(self, key)[:]
+                    )
         atoms = []
 
-        def rm_nan(x):
-            if not np.isnan(x).any():
-                return x
-            if len(x.shape) == 1:
-                return x[~np.isnan(x)]
-            return x[~np.isnan(x).any(axis=1)]
+        if GRP.boundary in data and GRP.pbc not in data:
+            data[GRP.pbc] = np.repeat(
+                [GRP.decode_boundary(data[GRP.boundary])], len(data[GRP.position]), axis=0
+            )
 
         for idx in range(len(data[GRP.position])):
             obj = ase.Atoms(
@@ -214,7 +225,7 @@ class ASEH5MD(H5MDBase):
                     rm_nan(data[GRP.velocity][idx]) if GRP.velocity in data else None
                 ),
                 cell=data[GRP.edges][idx] if GRP.edges in data else None,
-                pbc=(data[GRP.boundary][idx] if GRP.boundary in data else None),
+                pbc=data[GRP.pbc][idx] if GRP.edges in data else None,
             )
             if GRP.forces in data or GRP.energy in data or GRP.stress in data:
                 obj.calc = SinglePointCalculator(
